@@ -1,7 +1,7 @@
 /* vim: set cino= fo=croql sw=8 ts=8 sts=0 noet cin fdm=syntax : */
 
 /*
- * Copyright (c) 2010 Ali Polatel <alip@exherbo.org>
+ * Copyright (c) 2010, 2011 Ali Polatel <alip@exherbo.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -32,7 +32,9 @@
 
 /**
  * \file
- * Low level wrapper around ptrace internals
+ * \brief Pink's low level wrappers around \c ptrace(2) internals
+ *
+ * \ingroup g_trace
  **/
 
 #include <stdbool.h>
@@ -47,6 +49,8 @@
  * between normal traps and those caused by a syscall. This option may not work
  * on all architectures.
  *
+ * \ingroup g_trace
+ *
  * \note Availability: Linux
  **/
 #define PINK_TRACE_OPTION_SYSGOOD   (1 << 0)
@@ -58,6 +62,8 @@
  * a SIGSTOP. The PID for the new process can be retrieved with
  * pink_trace_geteventmsg().
  *
+ * \ingroup g_trace
+ *
  * \note Availability: Linux
  **/
 #define PINK_TRACE_OPTION_FORK      (1 << 1)
@@ -69,6 +75,8 @@
  * a SIGSTOP. The PID for the new process can be retrieved with
  * pink_trace_geteventmsg().
  *
+ * \ingroup g_trace
+ *
  * \note Availability: Linux
  **/
 #define PINK_TRACE_OPTION_VFORK     (1 << 2)
@@ -80,6 +88,8 @@
  * a SIGSTOP. The PID for the new process can be retrieved with
  * pink_trace_geteventmsg().
  *
+ * \ingroup g_trace
+ *
  * \note Availability: Linux
  **/
 #define PINK_TRACE_OPTION_CLONE     (1 << 3)
@@ -88,6 +98,8 @@
  * If this flag is set in the options argument of pink_trace_setup(), stop the
  * child at the next execve(2) call with (SIGTRAP | PTRACE_EVENT_EXEC << 8)
  *
+ * \ingroup g_trace
+ *
  * \note Availability: Linux
  **/
 #define PINK_TRACE_OPTION_EXEC      (1 << 4)
@@ -97,6 +109,8 @@
  * child at the completion of the next vfork(2) call with
  * (SIGTRAP | PTRACE_EVENT_VFORK_DONE << 8)
  *
+ * \ingroup g_trace
+ *
  * \note Availability: Linux
  **/
 #define PINK_TRACE_OPTION_VFORK_DONE (1 << 5)
@@ -111,6 +125,8 @@
  * context is available, the tracer cannot prevent the exit from happening at
  * this point.
  *
+ * \ingroup g_trace
+ *
  * \note Availability: Linux
  **/
 #define PINK_TRACE_OPTION_EXIT      (1 << 6)
@@ -118,6 +134,8 @@
 /**
  * All trace options OR'ed together.
  *
+ * \ingroup g_trace
+ *
  * \note Availability: Linux
  **/
 #define PINK_TRACE_OPTION_ALL \
@@ -142,6 +160,8 @@ extern "C" {
  * by this process will cause a SIGTRAP to be sent to it, giving the parent a
  * chance to gain control before the new program begins execution.
  *
+ * \ingroup g_trace
+ *
  * \note This function is used only by the child process; the rest are used
  * only by the parent.
  *
@@ -153,6 +173,8 @@ pink_trace_me(void);
 /**
  * Restarts the stopped child process.
  *
+ * \ingroup g_trace
+ *
  * \param pid Process ID of the child to be restarted.
  * \param sig If this is non-zero and not SIGSTOP, it is interpreted as the
  * signal to be delivered to the child; otherwise, no signal is delivered.
@@ -171,6 +193,8 @@ pink_trace_cont(pid_t pid, int sig, char *addr);
 /**
  * Convenience macro to resume the stopped child process.
  *
+ * \ingroup g_trace
+ *
  * \see pink_trace_cont
  **/
 #define pink_trace_resume(pid, sig) pink_trace_cont((pid), (sig), (char *)1)
@@ -178,6 +202,8 @@ pink_trace_cont(pid_t pid, int sig, char *addr);
 /**
  * Kills the traced child process with SIGKILL.
  *
+ * \ingroup g_trace
+ *
  * \param pid Process ID of the child to be killed.
  *
  * \return true on success, false on failure and sets errno accordingly.
@@ -189,6 +215,8 @@ pink_trace_kill(pid_t pid);
  * Restarts the stopped child process and arranges it to be stopped after
  * execution of a single instruction.
  *
+ * \ingroup g_trace
+ *
  * \param pid Process ID of the child to be restarted.
  * \param sig Treated the same as the signal argument of pink_trace_cont().
  *
@@ -201,6 +229,8 @@ pink_trace_singlestep(pid_t pid, int sig);
  * Restarts the stopped child process and arranges it to be stopped after
  * the entry or exit of the next system call.
  *
+ * \ingroup g_trace
+ *
  * \param pid Process ID of the child to be restarted.
  * \param sig Treated the same was as the signal argument of pink_trace_cont().
  *
@@ -214,6 +244,8 @@ pink_trace_syscall(pid_t pid, int sig);
  * Restarts the stopped child process and arranges it to be stopped after
  * the entry of the next system call.
  *
+ * \ingroup g_trace
+ *
  * \note Availability: FreeBSD
  *
  * \param pid Process ID of the child to be restarted.
@@ -228,6 +260,8 @@ pink_trace_syscall_entry(pid_t pid, int sig);
  * Restarts the stopped child process and arranges it to be stopped after
  * the exit of the next system call.
  *
+ * \ingroup g_trace
+ *
  * \note Availability: FreeBSD
  *
  * \param pid Process ID of the child to be restarted.
@@ -237,6 +271,39 @@ pink_trace_syscall_entry(pid_t pid, int sig);
  **/
 bool
 pink_trace_syscall_exit(pid_t pid, int sig);
+
+/**
+ * This request can be used to obtain information about the kernel thread, also
+ * known as light-weight process, that caused the traced process to stop.
+ *
+ * \note Availability: FreeBSD
+ * \since 0.0.6
+ *
+ * \param pid Process ID of the child
+ * \param info Pointer to a 'struct ptrace_lwpinfo'
+ * \param size Size of 'struct ptrace_lwpinfo'
+ *
+ * \return true on success, false on failure and sets errno accordingly.
+ **/
+bool
+pink_trace_lwpinfo(pid_t pid, void *info, size_t size);
+
+/**
+ * This request controls tracing for new child processes of a traced process.
+ * If the second argument is 'true', then new child processes will enable
+ * tracing and stop before executing their first instruction.
+ *
+ * \note Availability: FreeBSD
+ * \since 0.0.6
+ *
+ * \param pid Process ID of the child
+ * \param on true to follow forks, false otherwise.
+ *
+ * \return true on success, false on failure and sets errno accordingly.
+ **/
+bool
+pink_trace_followfork(pid_t pid, bool on);
+
 #endif /* defined(PINKTRACE_FREEBSD)... */
 
 #if defined(PINKTRACE_LINUX) || defined(DOXYGEN)
@@ -246,6 +313,8 @@ pink_trace_syscall_exit(pid_t pid, int sig);
  * EXIT event this is the child's exit status. For FORK, VFORK, CLONE and
  * VFORK_DONE events this is the process ID of the new process.
  *
+ * \ingroup g_trace
+ *
  * \note Availability: Linux
  *
  * \param pid Process ID of the child whose event is to be reported.
@@ -260,6 +329,8 @@ pink_trace_geteventmsg(pid_t pid, unsigned long *data);
 /**
  * Sets the tracing options.
  *
+ * \ingroup g_trace
+ *
  * \note Availability: Linux
  *
  * \param pid Process ID of the child to be setup.
@@ -274,6 +345,8 @@ pink_trace_setup(pid_t pid, int options);
  * Restarts the stopped child process and arranges it to be stopped after
  * the entry of the next system call which will *not* be executed.
  *
+ * \ingroup g_trace
+ *
  * \note Availability: Linux (2.6.14 or newer)
  *
  * \param pid Process ID of the child to be restarted.
@@ -290,6 +363,8 @@ pink_trace_sysemu(pid_t pid, int sig);
  * Restarts the stopped child process like pink_trace_sysemu() but also
  * singlesteps if not a system call.
  *
+ * \ingroup g_trace
+ *
  * \note Availability: Linux (2.6.14 or newer)
  *
  * \param pid Process ID of the child to be restarted.
@@ -311,6 +386,8 @@ pink_trace_sysemu_singlestep(pid_t pid, int sig);
  * stopped by the completion of this call; use wait(2) to wait for the child to
  * stop.
  *
+ * \ingroup g_trace
+ *
  * \param pid Process ID of the child to be attached.
  *
  * \return true on success, false on failure and sets errno accordingly.
@@ -322,6 +399,8 @@ pink_trace_attach(pid_t pid);
  * Restarts the stopped child as for pink_trace_cont(), but first detaches from
  * the process, undoing the reparenting effect of pink_trace_attach().
  *
+ * \ingroup g_trace
+ *
  * \param pid Process ID of the child to be detached.
  * \param sig Check the second argument of pink_trace_cont().
  *
