@@ -1,7 +1,7 @@
 /* vim: set cino= fo=croql sw=8 ts=8 sts=0 noet cin fdm=syntax : */
 
 /*
- * Copyright (c) 2010 Ali Polatel <alip@exherbo.org>
+ * Copyright (c) 2010, 2011 Ali Polatel <alip@exherbo.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -32,15 +32,21 @@
 
 /**
  * \file
- * Pink's trace utility functions
+ * \brief Pink's trace utility functions
+ *
+ * \ingroup g_util
  **/
 
 #include <stdbool.h>
 #include <sys/types.h>
 
+#include <pinktrace/gcc.h>
+
 /**
  * The index arguments should be smaller than this define.
  *
+ * \ingroup g_util
+ *
  * \see pink_util_get_arg
  * \see pink_decode_simple
  * \see pink_decode_string
@@ -63,7 +69,9 @@ extern "C" {
  * On Linux this reads a word at the given offset in the child's USER area, and
  * places it in res, aka PTRACE_PEEKUSER.
  *
- * \note Mostly for internal use, use higher level functions where possible.
+ * \ingroup g_util
+ *
+ * \warning Mostly for internal use, use higher level functions where possible.
  *
  * \param pid Process ID of the child whose USER area is to be read.
  * \param off Offset
@@ -81,7 +89,9 @@ pink_util_peek(pid_t pid, long off, long *res);
  * On Linux this reads a word at the given offset in the child's memory, and
  * places it in res, aka PTRACE_PEEKDATA.
  *
- * \note Mostly for internal use, use higher level functions where possible.
+ * \ingroup g_util
+ *
+ * \warning Mostly for internal use, use higher level functions where possible.
  *
  * \param pid Process ID of the child whose USER area is to be read.
  * \param off Offset
@@ -99,7 +109,9 @@ pink_util_peekdata(pid_t pid, long off, long *res);
  * On Linux this copies the word val to the given offset in the child's USER
  * area, aka PTRACE_POKEUSER.
  *
- * \note Mostly for internal use, use higher level functions where possible.
+ * \ingroup g_util
+ *
+ * \warning Mostly for internal use, use higher level functions where possible.
  *
  * \param pid Process ID of the child.
  * \param off Offset
@@ -117,7 +129,9 @@ pink_util_poke(pid_t pid, long off, long val);
  * On Linux this copies the word val to location addr in the child's memory,
  * aka PTRACE_PEEKDATA.
  *
- * \note Mostly for internal use, use higher level functions where possible.
+ * \ingroup g_util
+ *
+ * \warning Mostly for internal use, use higher level functions where possible.
  *
  * \param pid Process ID of the child.
  * \param off Offset
@@ -131,6 +145,8 @@ pink_util_pokedata(pid_t pid, long off, long val);
 /**
  * Copy the child's general purpose registers to the given location.
  *
+ * \ingroup g_util
+ *
  * \param pid Process ID of the child.
  * \param regs Pointer to the structure of registers. On FreeBSD this is
  * "struct reg" defined in <machine/reg.h>, on Linux this is "struct pt_regs"
@@ -144,6 +160,8 @@ pink_util_get_regs(pid_t pid, void *regs);
 /**
  * Set the child's general purpose registers.
  *
+ * \ingroup g_util
+ *
  * \param pid Process ID of the child.
  * \param regs Same as pink_util_get_regs()
  *
@@ -156,7 +174,9 @@ pink_util_set_regs(pid_t pid, const void *regs);
  * Move len bytes of data of process pid, at address addr, to our address space
  * dest.
  *
- * \note Mostly for internal use, use higher level functions where possible.
+ * \ingroup g_util
+ *
+ * \warning Mostly for internal use, use higher level functions where possible.
  *
  * \param pid Process ID of the child.
  * \param addr Address where the data is to be moved from.
@@ -171,7 +191,9 @@ pink_util_moven(pid_t pid, long addr, char *dest, size_t len);
 /**
  * Convenience macro to read an object
  *
- * \note Mostly for internal use, use higher level functions where possible.
+ * \ingroup g_util
+ *
+ * \warning Mostly for internal use, use higher level functions where possible.
  *
  * \see pink_util_moven
  **/
@@ -182,6 +204,8 @@ pink_util_moven(pid_t pid, long addr, char *dest, size_t len);
  * Like pink_util_moven() but make the additional effort of looking for a
  * terminating zero-byte.
  *
+ * \ingroup g_util
+ *
  * \note On FreeBSD this function is equivalent to pink_util_moven().
  * \note Mostly for internal use, use higher level functions where possible.
  **/
@@ -191,19 +215,23 @@ pink_util_movestr(pid_t pid, long addr, char *dest, size_t len);
 /**
  * Like pink_util_movestr() but allocates the string itself.
  *
- * \note Mostly for internal use, use higher level functions where possible.
+ * \ingroup g_util
+ *
+ * \warning Mostly for internal use, use higher level functions where possible.
  *
  * \return The string on success and NULL on failure and sets errno
  * accordingly.
  **/
 char *
-pink_util_movestr_persistent(pid_t pid, long addr);
+pink_util_movestr_persistent(pid_t pid, long addr) PINK_GCC_ATTR((malloc));
 
 /**
  * Copy len bytes of data to process pid, at address addr, from our address space
  * src.
  *
- * \note Mostly for internal use, use higher level functions where possible.
+ * \ingroup g_util
+ *
+ * \warning Mostly for internal use, use higher level functions where possible.
  *
  * \param pid Process ID of the child being traced
  * \param addr Address where the data is to be copied to
@@ -218,7 +246,9 @@ pink_util_putn(pid_t pid, long addr, const char *src, size_t len);
 /**
  * Convenience macro to write an object
  *
- * \note Mostly for internal use, use higher level functions where possible.
+ * \ingroup g_util
+ *
+ * \warning Mostly for internal use, use higher level functions where possible.
  *
  * \see pink_util_putn
  **/
@@ -230,8 +260,10 @@ pink_util_putn(pid_t pid, long addr, const char *src, size_t len);
  * Like pink_util_putn() but make the additional effort not to overwrite
  * unreadable addresses. Use this e.g. to write strings safely.
  *
+ * \ingroup g_util
+ *
  * \note Availability: Linux
- * \note Mostly for internal use, use higher level functions where possible.
+ * \warning Mostly for internal use, use higher level functions where possible.
  *
  * \param pid Process ID of the child being traced
  * \param addr Address where the data is to be copied to
@@ -246,8 +278,10 @@ pink_util_putn_safe(pid_t pid, long addr, const char *src, size_t len);
 /**
  * Convenience macro to write an object safely
  *
+ * \ingroup g_util
+ *
  * \note Availability: Linux
- * \note Mostly for internal use, use higher level functions where possible.
+ * \warning Mostly for internal use, use higher level functions where possible.
  *
  * \see pink_util_putn_safe
  **/
@@ -259,6 +293,8 @@ pink_util_putn_safe(pid_t pid, long addr, const char *src, size_t len);
 /**
  * Gets the last system call called by child with the given process ID.
  *
+ * \ingroup g_util
+ *
  * \note Architecture specific system calls on ARM architecture are negated so
  * that the user can distinguish between normal system calls and architecture
  * specific system calls.
@@ -275,6 +311,8 @@ pink_util_get_syscall(pid_t pid, pink_bitness_t bitness, long *res);
 /**
  * Sets the system call to the given value.
  *
+ * \ingroup g_util
+ *
  * \note On ARM architecture, this only works for EABI system calls.
  *
  * \param pid Process ID of the child whose system call is to be set.
@@ -290,20 +328,23 @@ pink_util_set_syscall(pid_t pid, pink_bitness_t bitness, long scno);
  * Gets the return value of the last system call called by child with the given
  * process ID.
  *
+ * \ingroup g_util
+ *
  * \param pid Process ID of the child whose system call return value is to be
  * returned.
  * \param res Pointer to store the result.
  *
  * \return true on success, false on failure and sets errno accordingly.
  **/
-PINK_NONNULL(2)
 bool
-pink_util_get_return(pid_t pid, long *res);
+pink_util_get_return(pid_t pid, long *res) PINK_GCC_ATTR((nonnull(2)));
 
 /**
  * Sets the return value of the last system call called by child with the given
  * process ID.
  *
+ * \ingroup g_util
+ *
  * \param pid Process ID of the child whose system call return value is to be
  * modified.
  * \param ret Return value to set.
@@ -316,6 +357,8 @@ pink_util_set_return(pid_t pid, long ret);
 /**
  * Get the given argument and place it in res.
  *
+ * \ingroup g_util
+ *
  * \param pid Process ID of the child whose argument is to be received.
  * \param bitness Bitness of the child
  * \param ind The index of the argument (0-5, see #PINK_MAX_INDEX)
@@ -323,13 +366,14 @@ pink_util_set_return(pid_t pid, long ret);
  *
  * \return true on success, false on failure and sets errno accordingly.
  **/
-PINK_NONNULL(4)
 bool
-pink_util_get_arg(pid_t pid, pink_bitness_t bitness, unsigned ind, long *res);
+pink_util_get_arg(pid_t pid, pink_bitness_t bitness, unsigned ind, long *res) PINK_GCC_ATTR((nonnull(4)));
 
 /**
  * Set the given argument
  *
+ * \ingroup g_util
+ *
  * \param pid Process ID of the child whose argument is to be set.
  * \param bitness Bitness of the child
  * \param ind The index of the argument (0-5, see #PINK_MAX_INDEX)
