@@ -1,7 +1,7 @@
 /* vim: set cino= fo=croql sw=8 ts=8 sts=0 noet cin fdm=syntax : */
 
 /*
- * Copyright (c) 2010 Ali Polatel <alip@exheribo.org>
+ * Copyright (c) 2010, 2011 Ali Polatel <alip@exheribo.org>
  * Based in part upon truss which is:
  *   Copyright (c) 1997 Sean Eric Fagan
  * All rights reserved.
@@ -99,7 +99,7 @@ pink_bitness_get(pid_t pid)
 	mib[2] = KERN_PROC_SV_NAME;
 	mib[3] = pid;
 
-	if (PINK_UNLIKELY(sysctl(mib, 4, progt, &len, NULL, 0) < 0))
+	if (PINK_GCC_UNLIKELY(sysctl(mib, 4, progt, &len, NULL, 0) < 0))
 		return PINK_BITNESS_UNKNOWN;
 
 	for (walk = bitness_types; walk->type; walk++) {
@@ -134,7 +134,7 @@ pink_util_get_syscall(pid_t pid, pink_bitness_t bitness, long *res)
 
 	assert(bitness == PINK_BITNESS_32 || bitness == PINK_BITNESS_64);
 
-	if (PINK_UNLIKELY(!pink_util_get_regs(pid, &r)))
+	if (PINK_GCC_UNLIKELY(!pink_util_get_regs(pid, &r)))
 		return false;
 
 	/*
@@ -160,16 +160,16 @@ pink_util_get_syscall(pid_t pid, pink_bitness_t bitness, long *res)
 }
 
 bool
-pink_util_set_syscall(pid_t pid, PINK_UNUSED pink_bitness_t bitness, long scno)
+pink_util_set_syscall(pid_t pid, PINK_GCC_ATTR((unused)) pink_bitness_t bitness, long scno)
 {
 	struct reg r;
 
-	if (PINK_UNLIKELY(!pink_util_get_regs(pid, &r)))
+	if (PINK_GCC_UNLIKELY(!pink_util_get_regs(pid, &r)))
 		return false;
 
 	r.r_rax = scno;
 
-	if (PINK_UNLIKELY(!pink_util_set_regs(pid, &r)))
+	if (PINK_GCC_UNLIKELY(!pink_util_set_regs(pid, &r)))
 		return false;
 
 	return true;
@@ -183,7 +183,7 @@ pink_util_get_return(pid_t pid, long *res)
 
 	assert(res != NULL);
 
-	if (PINK_UNLIKELY(!pink_util_get_regs(pid, &r)))
+	if (PINK_GCC_UNLIKELY(!pink_util_get_regs(pid, &r)))
 		return false;
 
 	errorp = !!(r.r_rflags & PSL_C);
@@ -197,7 +197,7 @@ pink_util_set_return(pid_t pid, long ret)
 {
 	struct reg r;
 
-	if (PINK_UNLIKELY(!pink_util_get_regs(pid, &r)))
+	if (PINK_GCC_UNLIKELY(!pink_util_get_regs(pid, &r)))
 		return false;
 
 	if (ret < 0) {
@@ -220,7 +220,7 @@ pink_util_get_arg(pid_t pid, pink_bitness_t bitness, unsigned ind, long *res)
 	assert(ind < PINK_MAX_INDEX);
 	assert(res != NULL);
 
-	if (PINK_UNLIKELY(!pink_util_get_regs(pid, &r)))
+	if (PINK_GCC_UNLIKELY(!pink_util_get_regs(pid, &r)))
 		return false;
 
 	switch (bitness) {
@@ -270,7 +270,7 @@ pink_util_set_arg(pid_t pid, pink_bitness_t bitness, unsigned ind, long arg)
 	assert(bitness == PINK_BITNESS_32 || bitness == PINK_BITNESS_64);
 	assert(ind < PINK_MAX_INDEX);
 
-	if (PINK_UNLIKELY(!pink_util_get_regs(pid, &r)))
+	if (PINK_GCC_UNLIKELY(!pink_util_get_regs(pid, &r)))
 		return false;
 
 	switch (bitness) {
@@ -340,7 +340,7 @@ pink_decode_string_persistent(pid_t pid, pink_bitness_t bitness, unsigned ind)
 
 	assert(ind < PINK_MAX_INDEX);
 
-	if (PINK_UNLIKELY(!pink_util_get_arg(pid, bitness, ind, &addr)))
+	if (PINK_GCC_UNLIKELY(!pink_util_get_arg(pid, bitness, ind, &addr)))
 		return NULL;
 
 	return pink_util_movestr_persistent(pid, addr);
@@ -355,10 +355,10 @@ pink_decode_socket_address(pid_t pid, pink_bitness_t bitness, unsigned ind, long
 	assert(ind < PINK_MAX_INDEX);
 	assert(paddr != NULL);
 
-	if (PINK_UNLIKELY(fd && !pink_util_get_arg(pid, bitness, 0, fd)))
+	if (PINK_GCC_UNLIKELY(fd && !pink_util_get_arg(pid, bitness, 0, fd)))
 		return false;
 
-	if (PINK_UNLIKELY(!pink_util_get_arg(pid, bitness, ind, &addr)
+	if (PINK_GCC_UNLIKELY(!pink_util_get_arg(pid, bitness, ind, &addr)
 				|| !pink_util_get_arg(pid, bitness, ind + 1, &addrlen)))
 		return false;
 
