@@ -1,7 +1,7 @@
 /* vim: set cino= fo=croql sw=8 ts=8 sts=0 noet cin fdm=syntax : */
 
 /*
- * Copyright (c) 2010 Ali Polatel <alip@exherbo.org>
+ * Copyright (c) 2010, 2011 Ali Polatel <alip@exherbo.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -77,3 +77,26 @@ pink_name_lookup(const char *name, pink_bitness_t bitness)
 
 	return -1;
 }
+
+long
+pink_name_lookup_with_length(const char *name, size_t length, pink_bitness_t bitness)
+{
+	long scno;
+
+	if (PINK_GCC_UNLIKELY(bitness != PINK_BITNESS_64))
+		return -1;
+	if (PINK_GCC_UNLIKELY(name == NULL || name[0] == '\0'))
+		return -1;
+
+	for (scno = 0; scno < nsys; scno++) {
+		if (!strncmp(sysnames[scno], name, length)) {
+#ifdef SYSCALL_OFFSET_IA64
+			return scno + SYSCALL_OFFSET_IA64;
+#else
+			return scno;
+#endif /* SYSCALL_OFFSET_IA64 */
+		}
+	}
+
+	return -1;
+}
